@@ -2,7 +2,7 @@
 from django.db.models import Q
 from django.urls import resolve, Resolver404
 
-from seo.models import PageMeta
+from seo.models import PageMeta, SearchQuery
 
 
 def _get_url_full_name(request):
@@ -44,3 +44,18 @@ def get_page_meta(request):
         )
     except PageMeta.DoesNotExist:
         return PageMeta()
+
+
+def log_search(query, filter_options, result_count):
+
+    options = ''
+
+    for k, v in filter_options.items():
+        if v:
+            options += '{}: {} \n'.format(k, v)
+
+    SearchQuery.objects.create(
+        query=query[:255],
+        filter_options=options,
+        result_count=result_count
+    )
